@@ -5,6 +5,7 @@ import os
 import shutil
 import subprocess
 import sys
+
 from datetime import date
 from datetime import datetime
 from datetime import timezone
@@ -18,11 +19,10 @@ from unittest.mock import patch
 import pytest
 
 import setuptools_scm._file_finders
-from .conftest import DebugMode
-from .wd_wrapper import WorkDir
+
 from setuptools_scm import Configuration
-from setuptools_scm import git
 from setuptools_scm import NonNormalizedVersion
+from setuptools_scm import git
 from setuptools_scm._file_finders.git import git_find_files
 from setuptools_scm._run_cmd import CommandNotFoundError
 from setuptools_scm._run_cmd import CompletedProcess
@@ -31,6 +31,9 @@ from setuptools_scm._run_cmd import run
 from setuptools_scm.git import archival_to_version
 from setuptools_scm.version import format_version
 
+from .conftest import DebugMode
+from .wd_wrapper import WorkDir
+
 pytestmark = pytest.mark.skipif(
     not has_command("git", warn=False), reason="git executable not found"
 )
@@ -50,7 +53,7 @@ def wd(wd: WorkDir, monkeypatch: pytest.MonkeyPatch, debug_mode: DebugMode) -> W
 
 
 @pytest.mark.parametrize(
-    "given, tag, number, node, dirty",
+    ("given", "tag", "number", "node", "dirty"),
     [
         ("3.3.1-rc26-0-g9df187b", "3.3.1-rc26", 0, "g9df187b", False),
         ("17.33.0-rc-17-g38c3047c0", "17.33.0-rc", 17, "g38c3047c0", False),
@@ -71,7 +74,8 @@ def test_root_relative_to(wd: WorkDir, monkeypatch: pytest.MonkeyPatch) -> None:
         """from setuptools import setup
 setup(use_scm_version={"root": "../..",
                        "relative_to": __file__})
-"""
+""",
+        encoding="utf-8",
     )
     res = run([sys.executable, "setup.py", "--version"], p)
     assert res.stdout == "0.1.dev0+d20090213"
@@ -86,7 +90,8 @@ def test_root_search_parent_directories(
     p.joinpath("setup.py").write_text(
         """from setuptools import setup
 setup(use_scm_version={"search_parent_directories": True})
-"""
+""",
+        encoding="utf-8",
     )
     res = run([sys.executable, "setup.py", "--version"], p)
     assert res.stdout == "0.1.dev0+d20090213"
@@ -102,7 +107,7 @@ def test_git_gone(wd: WorkDir, monkeypatch: pytest.MonkeyPatch) -> None:
     assert wd.get_version(fallback_version="1.0") == "1.0"
 
 
-@pytest.mark.issue("https://github.com/pypa/setuptools_scm/issues/298")
+@pytest.mark.issue("https://github.com/pypa/setuptools-scm/issues/298")
 @pytest.mark.issue(403)
 def test_file_finder_no_history(wd: WorkDir, caplog: pytest.LogCaptureFixture) -> None:
     file_list = git_find_files(str(wd.cwd))
@@ -111,7 +116,7 @@ def test_file_finder_no_history(wd: WorkDir, caplog: pytest.LogCaptureFixture) -
     assert "listing git files failed - pretending there aren't any" in caplog.text
 
 
-@pytest.mark.issue("https://github.com/pypa/setuptools_scm/issues/281")
+@pytest.mark.issue("https://github.com/pypa/setuptools-scm/issues/281")
 def test_parse_call_order(wd: WorkDir) -> None:
     git.parse(str(wd.cwd), Configuration(), git.DEFAULT_DESCRIBE)
 
@@ -148,7 +153,7 @@ def break_folder_permissions(path: Path) -> Generator[None, None, None]:
         sudo_devnull(["chgrp", "-R", str(original_stat.st_gid), path], check=True)
 
 
-@pytest.mark.issue("https://github.com/pypa/setuptools_scm/issues/707")
+@pytest.mark.issue("https://github.com/pypa/setuptools-scm/issues/707")
 def test_not_owner(wd: WorkDir) -> None:
     with break_folder_permissions(wd.cwd):
         assert git.parse(str(wd.cwd), Configuration())
@@ -158,7 +163,8 @@ def test_version_from_git(wd: WorkDir) -> None:
     assert wd.get_version() == "0.1.dev0+d20090213"
 
     parsed = git.parse(str(wd.cwd), Configuration(), git.DEFAULT_DESCRIBE)
-    assert parsed is not None and parsed.branch in ("master", "main")
+    assert parsed is not None
+    assert parsed.branch in ("master", "main")
 
     wd.commit_testfile()
     assert wd.get_version().startswith("0.1.dev1+g")
@@ -248,7 +254,7 @@ def test_git_version_unnormalized_setuptools(
     assert res == "17.33.0rc1"
 
     # but the version tag in the file is non-normalized (with the dash)
-    assert wd.cwd.joinpath("VERSION.txt").read_text() == "17.33.0-rc1"
+    assert wd.cwd.joinpath("VERSION.txt").read_text(encoding="utf-8") == "17.33.0-rc1"
 
 
 @pytest.mark.issue(179)
@@ -285,7 +291,8 @@ def test_git_dirty_notag(
         tag = datetime.now(timezone.utc).date().strftime(".d%Y%m%d")
     else:
         tag = ".d20090213"
-    assert version.startswith("0.1.dev1+g") and version.endswith(tag)
+    assert version.startswith("0.1.dev1+g")
+    assert version.endswith(tag)
 
 
 @pytest.mark.issue(193)
@@ -293,7 +300,7 @@ def test_git_dirty_notag(
 def test_git_worktree_support(wd: WorkDir, tmp_path: Path) -> None:
     wd.commit_testfile()
     worktree = tmp_path / "work_tree"
-    wd("git worktree add -b work-tree %s" % worktree)
+    wd(f"git worktree add -b work-tree {worktree}")
 
     res = run([sys.executable, "-m", "setuptools_scm", "ls"], cwd=worktree)
     assert "test.txt" in res.stdout
@@ -394,7 +401,7 @@ def test_git_archive_run_from_subdirectory(
     assert setuptools_scm._file_finders.find_files(".") == [opj(".", "test1.txt")]
 
 
-@pytest.mark.issue("https://github.com/pypa/setuptools_scm/issues/728")
+@pytest.mark.issue("https://github.com/pypa/setuptools-scm/issues/728")
 def test_git_branch_names_correct(wd: WorkDir) -> None:
     wd.commit_testfile()
     wd("git checkout -b test/fun")
@@ -412,7 +419,7 @@ def test_git_feature_branch_increments_major(wd: WorkDir) -> None:
     assert wd.get_version(version_scheme="python-simplified-semver").startswith("1.1.0")
 
 
-@pytest.mark.issue("https://github.com/pypa/setuptools_scm/issues/303")
+@pytest.mark.issue("https://github.com/pypa/setuptools-scm/issues/303")
 def test_not_matching_tags(wd: WorkDir) -> None:
     wd.commit_testfile()
     wd("git tag apache-arrow-0.11.1")
@@ -425,7 +432,7 @@ def test_not_matching_tags(wd: WorkDir) -> None:
     ).startswith("0.11.2")
 
 
-@pytest.mark.issue("https://github.com/pypa/setuptools_scm/issues/411")
+@pytest.mark.issue("https://github.com/pypa/setuptools-scm/issues/411")
 def test_non_dotted_version(wd: WorkDir) -> None:
     wd.commit_testfile()
     wd("git tag apache-arrow-1")
@@ -449,19 +456,19 @@ def test_non_dotted_tag_no_version_match(wd: WorkDir) -> None:
     assert wd.get_version().startswith("0.11.2.dev2")
 
 
-@pytest.mark.issue("https://github.com/pypa/setuptools_scm/issues/381")
+@pytest.mark.issue("https://github.com/pypa/setuptools-scm/issues/381")
 def test_gitdir(monkeypatch: pytest.MonkeyPatch, wd: WorkDir) -> None:
     """ """
     wd.commit_testfile()
     normal = wd.get_version()
-    # git hooks set this and break subsequent setuptools_scm unless we clean
+    # git hooks set this and break subsequent setuptools-scm unless we clean
     monkeypatch.setenv("GIT_DIR", __file__)
     assert wd.get_version() == normal
 
 
 def test_git_getdate(wd: WorkDir) -> None:
     # TODO: case coverage for git wd parse
-    today = date.today()
+    today = datetime.now(timezone.utc).date()
 
     def parse_date() -> date:
         parsed = git.parse(os.fspath(wd.cwd), Configuration())
@@ -492,6 +499,22 @@ def test_git_getdate_badgit(
         assert git_wd.get_head_date() is None
 
 
+def test_git_getdate_git_2_45_0_plus(
+    wd: WorkDir, caplog: pytest.LogCaptureFixture, monkeypatch: pytest.MonkeyPatch
+) -> None:
+    wd.commit_testfile()
+    git_wd = git.GitWorkdir(wd.cwd)
+    fake_date_result = CompletedProcess(
+        args=[], stdout="2024-04-30T22:33:10Z", stderr="", returncode=0
+    )
+    with patch.object(
+        git,
+        "run_git",
+        Mock(return_value=fake_date_result),
+    ):
+        assert git_wd.get_head_date() == date(2024, 4, 30)
+
+
 @pytest.fixture
 def signed_commit_wd(monkeypatch: pytest.MonkeyPatch, wd: WorkDir) -> WorkDir:
     if not has_command("gpg", args=["--version"], warn=False):
@@ -517,16 +540,16 @@ Expire-Date: 0
     return wd
 
 
-@pytest.mark.issue("https://github.com/pypa/setuptools_scm/issues/548")
+@pytest.mark.issue("https://github.com/pypa/setuptools-scm/issues/548")
 def test_git_getdate_signed_commit(signed_commit_wd: WorkDir) -> None:
-    today = date.today()
+    today = datetime.now(timezone.utc).date()
     signed_commit_wd.commit_testfile(signed=True)
     git_wd = git.GitWorkdir(signed_commit_wd.cwd)
     assert git_wd.get_head_date() == today
 
 
 @pytest.mark.parametrize(
-    "expected, from_data",
+    ("expected", "from_data"),
     [
         (
             "1.0",
@@ -555,7 +578,7 @@ def test_git_archival_to_version(expected: str, from_data: dict[str, str]) -> No
     assert format_version(version) == expected
 
 
-@pytest.mark.issue("https://github.com/pypa/setuptools_scm/issues/727")
+@pytest.mark.issue("https://github.com/pypa/setuptools-scm/issues/727")
 def test_git_archival_node_missing_no_version() -> None:
     config = Configuration()
     version = archival_to_version({}, config=config)
